@@ -1,5 +1,5 @@
 #######################################################################
-# $Id: Test.pm,v 1.6 2010-12-01 01:18:29 dpchrist Exp $
+# $Id: Test.pm,v 1.7 2010-12-02 21:33:34 dpchrist Exp $
 #######################################################################
 # package:
 #----------------------------------------------------------------------
@@ -9,7 +9,7 @@ package Dpchrist::Test;
 use strict;
 use warnings;
 
-our $VERSION  = sprintf "%d.%03d", q$Revision: 1.6 $ =~ /(\d+)/g;
+our $VERSION  = sprintf "%d.%03d", q$Revision: 1.7 $ =~ /(\d+)/g;
 
 1;
 
@@ -29,7 +29,7 @@ Dpchrist::Test - Perl module test utilities
 
 =head1 DESCRIPTION
 
-This documentation describes module revision $Revision: 1.6 $.
+This documentation describes module revision $Revision: 1.7 $.
 
 
 This is alpha test level software
@@ -86,20 +86,6 @@ Complete:
     $ cpan Bundle::Dpchrist
 
 
-The following warnings should not prevent installation:
-
-    Can't locate Dpchrist/ExtUtils/MakeMaker.pm in @INC (@INC contains: 
-    /etc/perl /usr/local/lib/perl/5.10.0 /usr/local/share/perl/5.10.0 /u
-    sr/lib/perl5 /usr/share/perl5 /usr/lib/perl/5.10 /usr/share/perl/5.1
-    0 /usr/local/lib/site_perl .) at Makefile.PL line XX.
-
-    Can't locate Test/Manifest.pm in @INC (@INC contains: /etc/perl /usr
-    /local/lib/perl/5.10.0 /usr/local/share/perl/5.10.0 /usr/lib/perl5 /
-    usr/share/perl5 /usr/lib/perl/5.10 /usr/share/perl/5.10 /usr/local/l
-    ib/site_perl .) at (eval X) line XX.
-    BEGIN failed--compilation aborted at (eval X) line XX.
-
-
 =head2 PREREQUISITES
 
 See Makefile.PL in the source distribution root directory.
